import QtQuick 1.1
import "../Common.js" as Common
import "../Stat.js" as Stat

Item
{
	property variant target
	objectName:	"scrollBar"
	id:scrollBar
	visible: track.height > thumb.height && !!target && target.contentHeight > 0

	width: backgroundLoader.item.width
	property Component background: FlickableScrollBarDefaultBackground{}
	property Component thumb: FlickableScrollBarDefaultThumb{}

	function calculateThumbHeight()
	{
		var tempHeight = 0;
		if(target && target.contentHeight > 0)
			tempHeight = (target.height / target.contentHeight) * track.height;
		return tempHeight > 16 ? tempHeight : 16;
	}
	function getTrackSize()
	{
		return track.height;
	}
	function calculateThumbPosition()
	{
		var thumbPos = 0;
		if(target.contentHeight > 0)
			thumbPos = calculateK() * target.contentY;
		return thumbPos;
	}
	function calculateContentPosition()
	{
		if(target.contentHeight == 0)
			return 0;
		thumb.height = calculateThumbHeight();
		var temp = thumb.y / calculateK();
		return temp;
	}
	function calculateK()
	{
		// k is constant of proportionality in equation
		// ThumbPos = k * target.contentY
		// calculated by boundary condition
		// target.contentY == target.contentHeight - target.height <==> ThumbPos == TrackHeight - ThumbHeight
		var nominator = getTrackSize() - calculateThumbHeight();
		var denominator = target.contentHeight - target.height;
		return denominator > 0 ? nominator / denominator : 1;
	}

	Item
	{
		anchors.fill: parent
		objectName:"scrollbarArea"

		Timer
		{
			property int scrollAmount
			id: scrollRepeater
			repeat: true
			interval: 20
			onTriggered:
			{
				target.contentY = Math.max(0, Math.min(target.contentY + scrollAmount, target.contentHeight - target.height));
			}
		}

		Loader
		{
			id: backgroundLoader
			height: parent.height
			sourceComponent: scrollBar.background
		}

		Item
		{
			id: track
			objectName:"scrollbarTrack"
			anchors {top: parent.top; topMargin: 1; bottom: parent.bottom; leftMargin: 1;}
			width: parent.width

			MouseArea
			{
				anchors.fill: parent
				onPressed:
				{
					scrollRepeater.scrollAmount = target.height * (mouseY < thumb.y ? -1 : 1)	// scroll by a page
					scrollRepeater.running = true;
				}
				onReleased:
				{
					scrollRepeater.running = false;
                    Stat.onButtonClick(Common.buildDelegatelessPath(track));
				}
				Clickable {}
				hoverEnabled : true
			}

			Item
			{
				id: thumb
				height: scrollBar.calculateThumbHeight();
				width: parent.width

				Loader
				{
					id: backgroundThumb
					height: parent.height
					width: parent.width
					sourceComponent: scrollBar.thumb
				}

				Connections
				{
					target: scrollBar.target ? scrollBar.target : null
					ignoreUnknownSignals: true
					onContentYChanged: {
						if (!mouseArea.drag.active)
						{
							thumb.y = calculateThumbPosition();
						}
					}
					onContentHeightChanged: {
						if (!mouseArea.drag.active)
						{
							thumb.y = calculateThumbPosition();
						}
					}
				}

				MouseArea
				{
					id: mouseArea
					anchors.fill: parent
					drag.target: parent
					drag.axis: Drag.YAxis
					drag.minimumY: 0
					drag.maximumY: track.height - height
					hoverEnabled : true

					Clickable { }
					onExited: thumb.y = calculateThumbPosition();
                    onReleased: Stat.onButtonClick(Common.buildDelegatelessPath(track));
					onPositionChanged:
					{
						if (pressedButtons == Qt.LeftButton && scrollBar.target)
							scrollBar.target.contentY = scrollBar.calculateContentPosition();
					}
				}
			}
		}
	}
}

