import QtQuick 1.1
import "slider_details" as Details

Item
{
	id: widget

	property variant target: widget
	property string property: "value"
	property int minValue: 0
	property int maxValue: 100
	property bool hasMarks1: false
	property bool hasMarks2: false
	property int orientation: Qt.Horizontal
    property variant labels // here is list of textual labels (labels supproted for horizontal orientation only)
    property variant textfont: fontStyles.standardCommonTextFont
    property string textcolor: "black"

	property int value: (minValue + maxValue) / 2

	OrientationHelper { id: xy; inverted: orientation != Qt.Horizontal }

	width: orientation == Qt.Horizontal ? parent.width : loader.width
	height: orientation == Qt.Horizontal ? column.height : parent.height

	property Item body: loader.item.body

	Column
	{
		id: column
		objectName: "Column"
		width: parent.width
		Item
		{
			id: flipper
			objectName: "Flipper"
			height: loader.height
			width: loader.width
			MirrorXY
			{
				id: loader
				objectName: "MirrorLoader"
				mirror: orientation != Qt.Horizontal
				body: Details.BodyMarks
				{
					id: sliderBody
					objectName: "SliderBody"
					target: widget.target
					property: widget.property
					minValue: widget.minValue
					maxValue: widget.maxValue
					hasMarks1: widget.hasMarks1
                    hasMarks2: widget.hasMarks2
				}
				Binding { target: loader.item; property: "width"; value: xy.get(widget, "width") }
				transform: Scale
				{
					origin.x: loader.width / 2
					origin.y: loader.height / 2
					xScale: 1
					yScale: orientation == Qt.Horizontal ? 1 : -1
				}
            }
		}
		ConditionalLoader
		{
			when: orientation == Qt.Horizontal && !!labels
			width: parent.width
            conditionSourceComponent: Item
			{
				property Item body: parent ? parent.parent.parent.body : null
				width: parent.width
				height: childrenRect.height
				Repeater
				{
					id: repeater
					model: body ? body.maxValue - body.minValue + 1 : 0
					Text
					{
						text: labels && labels.length > index ? labels[index] : index
                        font: widget.textfont
                        color: widget.textcolor
						anchors.left: parent.left;
						anchors.leftMargin:
						{
							var markX = body.getXForValue(body.minValue + index);
							var middleX = markX - width / 2;
							var rightBoundCorrectedX = Math.min(middleX, parent.width - width);
							var bothBoundsCorrectedX = Math.max(0, rightBoundCorrectedX);
							return bothBoundsCorrectedX;
						}
					}
				}
			}
		}
    }

    FocusImage
    {
        parent: flipper
        target: widget.body;
        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter
        tileHorizontally: true
        tileVertically: true
        widthClipperSize: -6
        heightClipperSize: -6
        border {
            top: 13
            bottom: 10
            left: 13
            right: 15
        }
        source: "../images/focuses/focus_footer_secondary.png"
    }

	Keys.onLeftPressed: orientation == Qt.Horizontal ? widget.body.decrementTargetValue() : null
	Keys.onRightPressed: orientation == Qt.Horizontal ? widget.body.incrementTargetValue() : null
	Keys.onUpPressed: orientation == Qt.Horizontal ? null : widget.body.incrementTargetValue()
	Keys.onDownPressed: orientation == Qt.Horizontal ? null : widget.body.decrementTargetValue()
}
