import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts

Column
{
	property variant fontStyles: Fonts.Online{}
	property variant context: MainWindow.online
	
	Localizer { id:tr; scope:"Online" }

	objectName:	"OnlineServiceStatistics"

    y: 1
	spacing: 10
	Text
	{
		anchors.left: parent.left
		text : tr.Localize("StatisticsHeader")
		font: fontStyles.standardBoldSubHeadingFont
	}
	
	Column
	{	
		id: reputationScaleBar

		width : parent.width
		height: childrenRect.height

		spacing: 12

		Row
		{
			id: bar
	
			Component
			{
				id:barSeparator
				Image
				{
				source: "../common/images/ksn/ksn_bar_separator.png"
				mirror: Window.Mirror			
				}
			}

			property int minimalFieldWidth: 6
			property int separatorWidth: 6 // pixel width of barSeparator image
			
			property int wholeBarWidth: reputationScaleBar.width - separatorWidth * 2 - minimalFieldWidth * 3
			property int threatsSummary: context.CloudInfo.threatSafe + context.CloudInfo.threatMalware + context.CloudInfo.threatPending
			property real multiplier: threatsSummary ? wholeBarWidth / threatsSummary : 0

			property int safeFieldWidth: context.CloudInfo.threatSafe * multiplier + minimalFieldWidth
			property int malwareFieldWidth: context.CloudInfo.threatMalware * multiplier + minimalFieldWidth
			property int pendingFieldWidth: context.CloudInfo.threatPending * multiplier + minimalFieldWidth

			BorderImage
			{ 
				width: parent.safeFieldWidth
				border {left: 2;}
				source: "../common/images/ksn/threat_safe_pattern.png"
				mirror: Window.Mirror
				horizontalTileMode: BorderImage.Repeat
			}
			Loader {sourceComponent: barSeparator}
			BorderImage
			{ 
				width: parent.malwareFieldWidth
				border {left: 0; right: 0;}
				source: "../common/images/ksn/threat_malware_pattern.png"
				mirror: Window.Mirror
				horizontalTileMode: BorderImage.Repeat
			}
			Loader {sourceComponent: barSeparator}
			BorderImage
			{ 
				width: parent.pendingFieldWidth
				border {right: 2;}
				source: "../common/images/ksn/threat_pending_pattern.png"
				mirror: Window.Mirror
				horizontalTileMode: BorderImage.Repeat
			}
		}
		Row
		{ 
			spacing: 20

			DataItem
			{
				imageSource: "../common/images/ksn/threat_safe_sample.png"
				dataType:	tr.Localize("ThreatSafe")
				objects:	context.CloudInfo ? tr.LocalizeNumber(context.CloudInfo.threatSafe) : ""
				postfix:	tr.Localize("ThreatSafeCount", {"SafeThreatsCount" : context.CloudInfo.threatSafe})
			}
			DataItem
			{
				imageSource: "../common/images/ksn/threat_malware_sample.png"
				dataType:	tr.Localize("ThreatMalware")
				objects:	context.CloudInfo ? tr.LocalizeNumber(context.CloudInfo.threatMalware) : ""
				postfix:	tr.Localize("ThreatMalwareCount", {"MalwareThreatsCount" : context.CloudInfo.threatMalware})		
			}
			DataItem
			{
				imageSource: "../common/images/ksn/threat_pending_sample.png"
				dataType:	tr.Localize("ThreatPending")
				objects:	context.CloudInfo ? tr.LocalizeNumber(context.CloudInfo.threatPending) : ""
				postfix:	tr.Localize("ThreatPendingCount", {"PendingThreatsCount" : context.CloudInfo.threatPending})
			}
		}
	}
	
	Column
	{
		anchors.left: parent.left
		anchors.right: parent.right
		spacing: 4
		
        	Item{ height: 7; width: parent.width}
		
		Text
		{
			text: tr.Localize("Ksn_LastInfo")
			font: fontStyles.boldNormal
			anchors.left: parent.left
			horizontalAlignment: Text.AlignLeft
		}
		
		Row
		{
			anchors.left: parent.left
			anchors.right: parent.right
			Text
			{ 
				text: tr.Localize("Ksn_UsersProtected") 
				font: fontStyles.normal
				horizontalAlignment: Text.AlignLeft
			}
			Text
			{
				text: context.CloudInfo ? tr.LocalizeNumber(context.CloudInfo.usersProtected) : ""
				font: fontStyles.boldNormal
				horizontalAlignment: Text.AlignLeft
			}
		}
		
		Row
		{
			anchors.left: parent.left
			anchors.right: parent.right
			Text
			{ 
				text: tr.Localize("Ksn_ThreatsDetected") 
				font: fontStyles.normal
				horizontalAlignment: Text.AlignLeft
			}
			Text
			{
				text: context.CloudInfo ? tr.LocalizeNumber(context.CloudInfo.threatsDetected) : ""
				font: fontStyles.boldNormal
				horizontalAlignment: Text.AlignLeft
			}
		}
		
		Text
		{
			anchors.bottom: parent.bottom
			anchors.bottomMargin: -16
			anchors.right: parent.right
			anchors.rightMargin: -16
			anchors.verticalCenter: parent.verticalCenter
			text : tr.Localize("LastConnectedText") + (context.CloudInfo ? tr.LocalizeDateTimeShort(context.CloudInfo.lastOnlineTime) : "")
			font: fontStyles.small
			color: "Gray"
		}
	}
}
