import QtQuick 1.1

Item
{
    id: innersView
    objectName: "innersView"
    property bool animationRunning: opacityAnimation.running || animation.running
	signal innersViewShow(string panelName)
	signal innersViewHide(string panelName)
	signal showHelp

    function show(panelName)
    {
    	innersViewShow(panelName);
        displayArea.show(panelName)
    }
    function isShowed(panelName)
    {
        return displayArea.isShowed(panelName)
    }
    function getCurrent()
    {
        return displayArea.getCurrent()
    }
    function get(panelName)
    {
        return displayArea.get(panelName)
    }
    function hide(panelName)
    {
        displayArea.hide(panelName)
    }
    function back()
    {
        displayArea.back()
    }
    function home()
    {
        displayArea.home()
    }
    function setVisible(visible)
    {
        opacity = visible ? 1 : 0
    }
	function getHelpId()
	{
		if (getCurrent().item.helpId != undefined)
		{
			return getCurrent().item.helpId;
		}
		else
		{
			console.log("InnersView::getHelpId: helpId property is not defined for this panel");
			return 0;
		}
	}

    anchors.fill: parent
    opacity: 0
    Behavior on opacity
    {
        SmoothedAnimation
        {
            id: opacityAnimation
            velocity: 4
        }
    }
    onOpacityChanged:
    {
        if (opacity == 0)
        {
        	var panelName = displayArea.current ? displayArea.current.item.objectName : "";
        	displayArea.reset();
        	innersView.innersViewHide(panelName);
        }
    }
    MouseEventsEater { enabled: opacity > 0 }

    Item
    {
        id: displayArea
        objectName: "displayArea"
        anchors.top: parent.top
        anchors.topMargin: 85 * dpiScaler.factor /* from guidelines */
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 35 /* footer */
        width: parent.width
        clip: true
        enabled: !innersView.animationRunning
        onEnabledChanged: 
        {
			updateFocusPosition();
        }
		function updateFocusPosition()
		{
        	if (enabled && visible && current)
        	{
        		displayArea.forceActiveFocus();
        		current.activationCompleted();
            }
		}
        anchors.horizontalCenter: parent.horizontalCenter

        Rectangle
        {
            anchors.fill: parent
            color: "white"
        }

        BorderImage
        {
            id: toolbarBackground
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: 41
            source: "../common/images/inner/toolbar.png"

            horizontalTileMode: BorderImage.Repeat
        }

        InnerPanel { id: panelProblemList; file: "../problem_list/ProblemList.qml" }
        InnerPanel { id: panelScan; file: "../scan/Scan.qml" }
        InnerPanel { id: panelUpdater; file: "../updater/Updater.qml" }
        InnerPanel { id: panelOnline; file: "../ksn/OnlineServices.qml" }
        InnerPanel { id: panelNewsList; file: "../news/NewsList.qml" }
        InnerPanel { id: panelNewsItem; file: "../news/NewsItem.qml" }
        InnerPanel { id: panelSearch; file: "./Search.qml" }
        InnerPanel { id: panelTools; file: "../main_window/AdvancedTools.qml" }
        InnerPanel { id: panelUpgrade; file: "../migration/Upgrade.qml" }
        InnerPanel { id: panelLicenseManager; file: "../license/LicenseManager.qml" }
        InnerPanel { id: panelAboutCloudProtection; file: "../ksn/AboutCloudProtection.qml" }
        InnerPanel { id: panelSafeBanking; file: "../safe_banking/SafeBanking.qml" }
		InnerPanel { id: panelUcpWizard; file: "../ucp/UcpWizard.qml" }
        function dynamicallyAddedPanels() {} // function is javasript object and any object in javascript is hash
        // all elements on left side organized in double linked list
        property variant first // first element on left side
        property variant last // last element on left side
        property variant current // visible element
        Connections
        {
            ignoreUnknownSignals: true
            target: displayArea.current ? displayArea.current : null
            onBack: displayArea.back()
            onHome: displayArea.home()
            onActivate: displayArea.show(panelName)
            onWindowChanged: displayArea.updateFocusPosition()
        }

        Rectangle
        {
            height: parent.height - toolbarBackground.height + 4
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.topMargin: toolbarBackground.height - 4
            width: 1
            color: "#e0e0e0"
        }

        Rectangle
        {
            height: parent.height - toolbarBackground.height + 4
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.topMargin: toolbarBackground.height - 4
            width: 1
            color: "#e0e0e0"
        }

        function canHome(panel)
        {
            return panel != first && (first != undefined || panel != current)
        }

        function reset()
        {
            if (current)
            {
                current.hide()
                current = undefined
            }
            while (first)
            {
                var temp = first.next
                first.prev = undefined
                first.next = undefined
                first = temp
            }
            last = undefined
        }
        function moveToRight(panel)
        {
            if (panel.prev || panel.next || first == panel)
            {
                if (panel.prev)
                    panel.prev.next = panel.next
                else
                    first = panel.next
                if (panel.next)
                    panel.next.prev = panel.prev
                else
                    last = panel.prev
                panel.next = panel.prev = undefined
            }
        }
        SequentialAnimation
        {
            id: animation
            property bool leftIsOld
            property alias oldPanel: oldPanelAnimation.target
            property alias newPanel: newPanelAnimation.target
            property int velocity: 1200
            ParallelAnimation
            {
                SmoothedAnimation
                {
                    id: oldPanelAnimation
                    property: "x";
                    to: (Window.Mirror ? -1 : 1) * (animation.leftIsOld ? -1 : 1) * (target ? target.width : 0)
                    velocity: animation.velocity
                }
                SmoothedAnimation
                {
                    id: newPanelAnimation
                    property: "x";
                    to: 0;
                    velocity: animation.velocity
                }
            }
            ScriptAction
            {
                script:
                {
                    animation.oldPanel.hide()
                }
            }
        }
        function commonAnimate(leftPanel, rightPanel, leftIsOld)
        {
            var oldPanel = leftIsOld ? leftPanel : rightPanel
            var newPanel = leftIsOld ? rightPanel : leftPanel
            newPanel.x = (Window.Mirror ? -1 : 1) * (leftIsOld ? 1 : - 1) * newPanel.width
            newPanel.show()
            animation.oldPanel = oldPanel
            animation.newPanel = newPanel
            animation.leftIsOld = leftIsOld
            animation.running = true
        }
        function animateShow(leftPanel, rightPanel)
        {
            commonAnimate(leftPanel, rightPanel, true);
        }
        function animateHide(leftPanel, rightPanel)
        {
            commonAnimate(leftPanel, rightPanel, false);
        }

        function dynamicallyAddPanel(panelName)
        {
            var prefix = "panel";
            var featureName = panelName.substr(prefix.length)
            dynamicallyAddedPanels[panelName] =
                Qt.createQmlObject('import QtQuick 1.1; InnerPanel { file: "../'+ featureName + '/' + featureName + '.qml"; parent: displayArea; }', displayArea);
        }
        function show(panelName)
        {
            var panel = get(panelName);
            if (panel == current)
                return;
            moveToRight(panel)
            innersView.setVisible(true)
            if (!current)
            {
                panel.x = 0;
                panel.show();
                current = panel;
                return
            }
            if (last)
            {
                last.next = current
                current.prev = last
                last = current
            }
            else
            {
                first = current
                last = current
            }
            animateShow(current, panel)
            current = panel
        }
        function isShowed(panelName)
        {
            var panel = get(panelName)
            return panel && (current == panel || panel.prev || panel.next || first == panel);
        }
        function getCurrent()
        {
            return current;
        }
        function get(panelName)
        {
            try
            {
                return eval(panelName);
            }
            catch (e)
            {
                if (!dynamicallyAddedPanels[panelName])
                    dynamicallyAddPanel(panelName);
                return dynamicallyAddedPanels[panelName];
            }
        }
        function hide(panelName)
        {
            if (!current)
                return
            var panel = get(panelName)
            if (panel == current)
                back()
            else
                moveToRight(panel)
        }
        function back()
        {
            if (!current)
                return
            if (last)
            {
                animateHide(last, current)
                current = last
                last = last.prev
                if (last)
                    last.next = undefined
                else
                    first = undefined
                current.prev = undefined
                current.next = undefined
            }
            else
            {
                home()
            }
        }
        function home()
        {
            innersView.setVisible(false);
            mainView.forceActiveFocus()
        }
    }

    BorderImage
    {
        id: mainBackground
        anchors {
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }
        height: 35

        border { left: 5; bottom: 5; right: 5;}
        source: "../common/images/main_window/bg_small_bottom.png"

        Rectangle
        {
            id: firstBottomBorder
            height: 1
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.top
            color: "white"
        }

        Rectangle
        {
            id: secondBottomBorder
            height: 1
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: firstBottomBorder.top
            color: "#dfdfdf"
        }
    }



    MainFooter
    {
        objectName: "mainFooter"
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: displayArea.bottom
        anchors.bottom: parent.bottom
        textColor: "#82ccf8"
        textcolorHovered: "#aedefa"
        textcolorPressed: "#82ccf8"
        focusSource: "../common/images/focuses/focus_footer_secondary.png"
        onShowHelp: innersView.showHelp()
    }
    Keys.onPressed:
    {
        if ((event.key == Qt.Key_Left && event.modifiers & Qt.AltModifier) || (event.key == Qt.Key_Backspace))
            back();
        else
            event.accepted = false;
    }
}
