import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../dashboard" as Dashboard
import "../common/ViewManager.js" as ViewManagerForBackView
import "../common/EnumHelper.js" as EnumHelper
import "../common/border" as Border
import "../common/fonts" as Fonts
import "../common/HelpMapper.js" as HelpMapper
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/Stat.js" as Stat

Widgets.FlipableY
{
	id: flipPanel

	property variant defaultButtonManager: defaultButtonManagerId

	Widgets.DefaultButtonManager{id: defaultButtonManagerId}
	Keys.forwardTo: defaultButtonManagerId
	focus: true

	objectName: "TopFlipPanel"
    property int panelWidth: 729
	property int panelHeight: 547
	width: childrenRect.width
	height: childrenRect.height

	front: mainViewBordered
	back: backViewBordered

	property bool firstShow: true
	animated: !firstShow
	
	Localizer { id:tr; scope:"MainWindow" }

	LayoutMirroring.enabled: Window.Mirror
	LayoutMirroring.childrenInherit: true

	function showPage(page)
	{
		var separatorPosition = page.search(":");
		if (separatorPosition == -1) separatorPosition = page.length;
		if (!separatorPosition)
			return;
		var currentPage = page.slice(0, separatorPosition);
		var page = page.slice(separatorPosition + 1);

        var mapOfWindowParams = {
            "ActivationWizard":		{path: "../activation/ActivationWizard.qml", isOnBackSide: true},
            "MigrationWizard":		{path: "../migration/MigrationWizard.qml", isOnBackSide: true},
            "Updater":				{panel: "panelUpdater", isOnBackSide: false},
            "ProblemList":			{panel: "panelProblemList", isOnBackSide: false},
            "Scan":					{panel: "panelScan", isOnBackSide: false},
            "Online":				{panel: "panelOnline", isOnBackSide: false},
            "NewsList":				{panel: "panelNewsList", isOnBackSide: false},
            "NewsItem":				{panel: "panelNewsItem", isOnBackSide: false},
            "Search":				{panel: "panelSearch", isOnBackSide: false},
            "Tools":				{panel: "panelTools", isOnBackSide: false},
            "Upgrade":				{panel: "panelUpgrade", isOnBackSide: false},
            "LicenseManager":		{panel: "panelLicenseManager", isOnBackSide: false},
            "SafeBanking":          {panel: "panelSafeBanking", isOnBackSide: false, productType: "kis"},
			"UcpWizard":			{panel: "panelUcpWizard", isOnBackSide: false}
        };

		var params = mapOfWindowParams[currentPage];
        if (!params || (!params.path && !params.panel) || (params.productType && params.productType !== ProductTypeHelper.productTypeToString(MainWindow)))
		{
				console.log("windowPage for '" + currentPage + "' has not been found");
				return;

		}
		firstShow = firstShow && currentPage == "ActivationWizard"
		var newPage = undefined;
        if (params.isOnBackSide)
		{
			newPage = backView.showPage(params);
		}
		else
		{
			mainView.showPage(params);
			var currentPage = mainView.getInnerPanel().getCurrent();
			if (flipPanel.isFlipped())
				backView.closePage();
			if(currentPage && currentPage.showPage)
				currentPage.showPage(page);
		}
		if (page && newPage && (typeof newPage.showPage == "function"))
			newPage.showPage(page);
		firstShow = false;
	}

	Border.BorderedContent
	{
		id: backViewBordered
		objectName: "backViewBordered"
		content: backView
		enabled: flipPanel.isFlipped()
    }

	Widgets.HotKeyScope
	{
		id: backViewScope
		width: panelWidth
		height: panelHeight
		parent: backViewBordered
		CustomLoader
		{
			id: backView
			objectName: "backView"
			width: panelWidth
			height: panelHeight

			function getHelpId()
			{
				return item.getHelpId();
			}

			function showPage(params)
			{
				if (file == params.path)
					return;
				viewManager().goTop();
				file = params.path;
				viewManager().goTop();
				viewManager().show(eval(backView));
				item.duration = 0;
				return backView;
			}
			function closePage()
			{
				backView.file = "";
				flipPanel.flipBack();
			}
			Connections
			{
				target: backView.item
				onClose: Window.Close()
				onCancel: backView.closePage()
				onShowHelp: flipPanel.showHelp()
			}
			Connections
			{
				target: flipPanel
				onAnimationFinished:
				{
					flipPanel.back.focus = isFlipped() ? true : false;
					flipPanel.front.focus = isFlipped() ? false : true;
					if (!flipPanel.isFlipped())
						backView.viewManager().doBack();
					else
					{
						if (backView.item.animationCompleted)
							backView.item.animationCompleted();
					}
				}
			}
			function viewManager() {return ViewManagerForBackView;}

			onStatusChanged:
			{
				switch (status)
				{
					case Loader.Null:
					{
						if (!file)
							flipPanel.flipBack();
						break;
					}
					case Loader.Error:
					{
						source = "";
						closePage();
						break;
					}
				}
			}
			onLoaded:
			{
				flipPanel.flip();
			}
		}
	}

	Border.BorderedContent {
		id: mainViewBordered
		content: mainView
		enabled: !flipPanel.isFlipped()
    }

	Widgets.HotKeyScope
	{
		id: mainView
		parent: mainViewBordered
		width: panelWidth
		height: panelHeight
		objectName: "MainView"
        property int helpId: HelpMapper.MainWindowHelpId

		function showPage(params)
		{
			if (params.panel)
				innersView.show(params.panel);
		}

		function getInnerPanel()
		{
			return innersView.getCurrent();
		}

		function getHelpId()
		{
			if (innersView.enabled)
				return innersView.getHelpId();
			return helpId;
		}

		Item
		{
			id: backLayer
			objectName: "BackLayer"
			anchors.fill: parent
            enabled: innersView.opacity == 0

			Connections
			{
				target: innersView
				onInnersViewShow: backLayer.enabled = false;
				onInnersViewHide:
				{
					backLayer.enabled = true;
					// TODO: need to restore focus item
				}
				onShowHelp: flipPanel.showHelp()
            }

            BorderImage
            {

            }

            Dashboard.Dashboard
            {
                id: dashboard
                tabOrder: 1
                objectName: "dashboard"
                anchors.top: parent.top
                anchors.topMargin: 81 * dpiScaler.factor /* from guideline */
                height: 297 * dpiScaler.factor
                anchors.left   : parent.left
                anchors.right  : parent.right
                property bool featureBoxCoveredMe: featureBox.canDown
                visible: !featureBoxCoveredMe

                function onNavigateTo()
                {
                    Stat.onNavigateTo(objectName);
                    MainWindow.dashboard.IPM.reportShowStatistics();
                }

                Connections
                {
                    target: MainWindow.dashboard.IPM;
                    onContentChanged: MainWindow.dashboard.IPM.reportShowStatistics();
                }

                Component.onCompleted:
                {
                    onNavigateTo()
                }
                onProblemListButtonPressed: innersView.show("panelProblemList")
            }

			FeatureBox
			{
				id: featureBox
				property int tabOrder: 3
                objectName: "featureBox"
                anchors.bottom: parent.bottom
				anchors.left:   parent.left
				anchors.right:  parent.right
                onActivate:	 innersView.show(panelName)
                hideTongue: innersView.opacity === 1
            }

            Image
            {
                id: footerSeparator
                source: "../common/images/main_window/featurebox/separator.png"
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 35
                width: parent.width
            }

            MainFooter
            {
                id: mainFooter
                tabOrder: 4
                objectName: "mainFooter"
                anchors.left:   parent.left
                anchors.right:  parent.right
                anchors.bottom: parent.bottom
                anchors.top: footerSeparator.bottom
                textColor: "#82ccf8"
                textcolorHovered: "#bde4fb"
                focusSource: "../common/images/focuses/focus_footer_main.png"
            }
            Connections
            {
                target: mainFooter
                onShowHelp: flipPanel.showHelp()
            }
		}

		InnersView
		{
			id: innersView
			objectName: "innersView"
			enabled: opacity == 1

			onOpacityChanged:
			{
				if (opacity == 0)
					dashboard.onNavigateTo()
			}
		}

		Item
		{
			id: topLayer
			objectName: "TopLayer"
			enabled: !innersView.animationRunning
            anchors.fill: parent

			Widgets.Button
			{
				objectName: "productInfo"
				
				anchors.left: parent.left
				anchors.leftMargin: 15 /* dashboard margin */ + 25 /* from guideline */
				tabOrder: 5
				y: 30 /* from guideline */
				iconImage: "../images/main_window/logo.png"

				onClicked: MainWindow.startPage.ShowProductInfo();

				focusRectEnabled: false
                Widgets.FocusImage
                {
                    anchors {
                        verticalCenter: parent.verticalCenter
                        verticalCenterOffset: -1
                        horizontalCenter: parent.horizontalCenter
                    }
                    source: "../common/images/focuses/focus_logo.png"
                }
				
			}

            FocusScope
            {
                id: windowButtons
                property int tabOrder: 8
                objectName: "WindowButtons"
                anchors.right: parent.right
                anchors.rightMargin: 15
                anchors.top: parent.top
                width: childrenRect.width
                height: childrenRect.height
                Row
                {
                    spacing: 0
                    objectName: "WindowButtonsRow"

                    Widgets.KeyNavigation
                    {
                        id: windowButtonsKeyNavigations

                        Component.onCompleted:
                        {
                            var items = [
                                searchButton,
                                minimizeButton,
                                closeButton];
                            focusedItems = items;
                        }
                    }
                    Keys.onRightPressed: windowButtonsKeyNavigations.onSetNext(event)
                    Keys.onLeftPressed: windowButtonsKeyNavigations.onSetPrevious(event)
                    Widgets.Button
                    {
                        property bool searchMode: innersView.get("panelSearch") == innersView.getCurrent()
                        property string prefix: "../images/window/windowbutton_search_";
                        objectName: "Search"
                        tabOrder: 0
                        setFocusOnPressed: true
                        focus: true
                        id: searchButton
                        iconImage: searchMode ? prefix + "pressed.png" : prefix + "normal.png"
                        iconHoverImage: searchMode ? prefix + "pressed.png" : prefix + "hover.png"
                        iconPressedImage: searchMode ? prefix + "pressed.png" : prefix + "normal.png"
                        mirror: Window.Mirror
                        onClicked:
                        {
                            var showed = innersView.getCurrent() == innersView.get("panelSearch")
                            if (showed)
                                innersView.back()
                            else
                                innersView.show("panelSearch")
                        }
                    }
                    Widgets.Button
                    {
                        tabOrder: 0
                        setFocusOnPressed: true
                        id: minimizeButton
                        objectName: "Minimize"
                        iconImage: "../images/window/windowbutton_minimize2_normal.png"
                        iconHoverImage: "../images/window/windowbutton_minimize2_hover.png"
                        iconPressedImage: "../images/window/windowbutton_minimize2_pressed.png"
                        mirror: Window.Mirror
                        onClicked: Window.Minimize()
                    }
                    Widgets.Button
                    {
                        tabOrder: 0
                        setFocusOnPressed: true
                        id: closeButton
                        objectName: "Close"
                        iconImage: "../images/window/windowbutton_close2_normal.png"
                        iconHoverImage: "../images/window/windowbutton_close2_hover.png"
                        iconPressedImage: "../images/window/windowbutton_close2_pressed.png"
                        mirror: Window.Mirror
                        onClicked: Window.Close()
                    }
                }
            }

			Row
			{
				id: topButtons
				property int tabOrder: 7
				visible: moveSearch.state == "Hide"
				anchors.right: parent.right
                anchors.rightMargin: 12 /* right margin */
				anchors.top: parent.top
                anchors.topMargin: 40
				objectName: "topButtons"

				Widgets.KeyNavigation
				{
					id: topButtonsKeyNavigations

					Component.onCompleted:
					{
						var items = [
							news,
							cloud,
							myAccount,
							reports,
							settings];
						focusedItems = items;
					}
				}
				Keys.onRightPressed: topButtonsKeyNavigations.onSetNext(event)
				Keys.onLeftPressed: topButtonsKeyNavigations.onSetPrevious(event)

                spacing: 5
				TopBarButton
				{
					id: news
					objectName: "NewsButton"
					iconImage: "../images/main_window/topbar/news_normal.png"
					iconHoverImage: "../images/main_window/topbar/news_hover.png"
					iconPressedImage: "../images/main_window/topbar/news_pressed.png"
					onClicked: { innersView.show("panelNewsList"); }
                    visible: { MainWindow.startPage.AllNewsCount > 0; }
				}
				TopBarButton
				{
					id: cloud
					objectName: "CloudButton"
					iconImage: "../images/main_window/topbar/cloud_normal.png"
					iconHoverImage: "../images/main_window/topbar/cloud_hover.png"
					iconPressedImage: "../images/main_window/topbar/cloud_pressed.png"
					onClicked: { innersView.show("panelOnline"); }
				}
				TopBarButton
				{
					id: myAccount
					objectName: "MyAccountButton"
					iconImage: "../images/main_window/topbar/MyAccount_normal.png"
					iconHoverImage: "../images/main_window/topbar/MyAccount_hover.png"
					iconPressedImage: "../images/main_window/topbar/MyAccount_pressed.png"
					onClicked: { MainWindow.MyAccountAction.Invoke(); }
				}
				TopBarButton
				{
					id: reports
					objectName: "ReportButton"
					iconImage: "../images/main_window/topbar/reports_normal.png"
					iconHoverImage: "../images/main_window/topbar/reports_hover.png"
					iconPressedImage: "../images/main_window/topbar/reports_pressed.png"
					onClicked: { MainWindow.startPage.ShowReports(); }
				}
				TopBarButton
				{
					id: settings
					objectName: "SettingsButton"
					iconImage: "../images/main_window/topbar/settings_normal.png"
					iconHoverImage: "../images/main_window/topbar/settings_hover.png"
					iconPressedImage: "../images/main_window/topbar/settings_pressed.png"
					onClicked: { MainWindow.startPage.ShowSettings(); }
				}

                Component.onCompleted:
                {
                    news.width = reports.width = settings.width = Math.max(news.width, reports.width, settings.width);
                }
			}

			Item
			{
                objectName: "Search"
                anchors.right: parent.right
                anchors.rightMargin: 15 /* right margin */
                anchors.bottom: parent.top 
                anchors.bottomMargin: parent.top -75
                width: moveSearch.width
                height: moveSearch.height
                clip: true
				SlidePanel
				{
					id: moveSearch
					objectName: "SlidePanel"
					anchors.right: parent.right

					onHide:-parent.height
					onShow:0

					width: search.width;
					height: search.height;
					color: "transparent"

					property alias text: search.text
					property bool slidePanelAnimatationRunning: false
					property bool searchActivated: slidePanelAnimatationRunning && enabled && (state == "Show")
					onAnimationStarted: slidePanelAnimatationRunning = false
					onAnimationFinished: slidePanelAnimatationRunning = true
					onSearchActivatedChanged:
					{
						if (searchActivated)
							search.setActiveFocus();
					}

					SearchBox
					{
						id: search
						onTextChanged:
						{
							var panel = innersView.get("panelSearch").item;
							if (panel)
								panel.updateSearchList(moveSearch.text);
							search.sfocus = true
						}
					}
				}
			}

		}
        Component.onCompleted: mainView.forceActiveFocus()
	}
	Widgets.DPIScaler
	{
		id: dpiScaler
		changeSize: true
		widthProperty: "panelWidth"
		heightProperty: "panelHeight"
	}
	function showHelp()
	{
		var helpId = (flipPanel.isFlipped() ? backView : mainView).getHelpId();
		if (helpId)
			Help.Show(helpId);
	}
	Keys.onPressed:
	{
		if (event.key == Qt.Key_F1)
			showHelp();
		else if (event.key == Qt.Key_Escape)
		{
			if (flipPanel.isFlipped())
				backView.closePage();
			else
				Window.Close();
		}
		else 
			event.accepted = false;
	}
}
