import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets
import "../common/DateTime.js" as DateTime

FocusScope
{
    id: frontView
	property variant commonFontStyles: Fonts.Common{}
	height: parent.height - y
	objectName: "frontView"
    property int topMargin: 8
    property int leftMargin: 20
    focus: true

    Localizer { id:tr; scope:"ScanTask" }

	function setActiveFocus()
	{
		scanButton.forceActiveFocus();
	}

	Widgets.KeyNavigation
	{
		id: topKeyNavigations

		Component.onCompleted:
		{
			var items = [
				scanButton,
				info];
			focusedItems = items;
		}
	}
	Keys.onRightPressed: topKeyNavigations.onSetNext(event)
	Keys.onLeftPressed: topKeyNavigations.onSetPrevious(event)

    BorderImage
    {
        id: scanTaskBackground
        anchors.fill: parent
        border{left:5; right:5; top: 5; bottom:5}
        horizontalTileMode: BorderImage.Repeat
        verticalTileMode: BorderImage.Repeat
        source: "../common/images/scan/scan_task_background.png"
    }

    Text
    {
        id:		headerInfo
        text:	scan.scanHeader
        anchors.top: parent.top
        anchors.topMargin: 16
        anchors.left: parent.left
        anchors.leftMargin: frontView.leftMargin
        font: commonFontStyles.standardBoldSubHeadingFont
    }
					
	ScanButton
	{
		id: scanButton
        anchors.left: headerInfo.left
        anchors.top: headerInfo.bottom
        anchors.topMargin: frontView.topMargin
		objectName: contextScan.IsRunning ? "ScanButtonStop" : "ScanButtonStart"
		focus: true
		context: scan.contextScan
		enabled:
		{
			if(contextScan == undefined)
				return false
			if(contextScan.IsRunning && !contextScan.IsStopping)
				return contextScan.CanStop;
			return contextScan.CanStart;
		}
		onClickStart:
		{
			if(!contextScan.IsRunning && contextScan.CanResume)
			{
				askPanel.state = "askResumeScan"
				setBackPosition()
			}
			else
			{
				startScan()
			}
		}
		onClickStop:
		{
			askPanel.state = "askStopScan"
			setBackPosition()
		}
    }

	FocusScope
	{
		objectName: "info"
		id: info
		anchors.left: scanButton.right
        anchors.leftMargin: 16
		anchors.right: parent.right
        anchors.top: scanButton.top
        anchors.bottom: parent.bottom

		Widgets.KeyNavigation
		{
			id: infoKeyNavigations

			Component.onCompleted:
			{
				var items = [
					commonText,
					specific];
				focusedItems = items;
			}
		}
		Keys.onDownPressed: infoKeyNavigations.onSetNext(event)
		Keys.onUpPressed: infoKeyNavigations.onSetPrevious(event)

		// common specific
		FocusScope
		{
			id:		commonText
			width:	parent.width
			height: column.height
			objectName: "common"
			focus: true
			anchors.top: parent.top
            anchors.topMargin: 2

			// Failed specific
			Column
			{
				id:			descriptionForFailedScan
				width:		parent.width
				height:		parent.height
                spacing:	2
                visible:	contextScan.IsFailed;
                anchors.left: parent.left

				Row
				{
                    anchors.left: parent.left
					Text{text: tr.Localize("SinceTaskFailDescription"); font: commonFontStyles.standardCommonTextFont}
                    Widgets.Hyperlink
                    {
		            	setFocusOnPressed: true
						objectName: "DurationSinceLastStop"
		            	tabOrder: 1
		            	focus: contextScan.IsFailed
                        text: tr.Localize("DurationSinceLastStopText", {"DurationSinceLastStop" : DateTime.localizeTimeIntervalFromDateFullFormat(contextScan.DurationSinceLastStop, tr)})
                        onClicked: contextScan.ShowScanObjectReport();
                    }
				}
				Text
				{
                    anchors.left: parent.left
                    anchors.right: parent.right
                    horizontalAlignment: Text.AlignLeft
					text: tr.Localize("Error_" + contextScan.LastErrorDescription, "DefaultErrorDescription", {"DefaultErrorValue":contextScan.LastError});
					font: commonFontStyles.standardCommonTextFont
					wrapMode: 	Text.Wrap
				}
			}
			// NeverRun specific
			Text
			{
				id:			descriptionForNeverRanScan
				width:		parent.width - 20
                anchors.top: parent.top
                anchors.topMargin: 2
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                horizontalAlignment: Text.AlignLeft
				text:		scan.firstTimeRun
				wrapMode: 	Text.Wrap
                lineHeight: 1.1

				font: commonFontStyles.standardCommonTextFont
                visible: scan.contextScan.IsNeverRun && !descriptionForFailedScan.visible;
			}
			Column
			{
				id: column
				objectName: "column"
				width:		parent.width
                spacing:	3
				visible:	!descriptionForNeverRanScan.visible && !descriptionForFailedScan.visible 

                Item
				{
					id: textTime
					objectName: "row"
                    height: childrenRect.height
                    width: parent.width
                    anchors.left: parent.left
					Text
					{
                        id: textTimeText
                        anchors.left: parent.left
						text: contextScan.IsRunning ? tr.Localize("RemainingTimeName") : 
						(contextScan.IsCompleted ?
						 tr.Localize("DurationSinceLastCompletedScanName") :
						 tr.Localize("DurationSinceLastInterruptedScanName"));
						font: commonFontStyles.standardCommonTextFont
					}
                    Widgets.Hyperlink
					{
                        anchors.left: textTimeText.right
                        anchors.right: parent.right
                        anchors.rightMargin: 10
		            	setFocusOnPressed: true
		            	tabOrder: 1
		            	focus: contextScan.IsRunning || !contextScan.IsFailed
                        objectName: "time"
                        id: time
                        text:
                        {
							if(contextScan.IsRunning)
							{
								return DateTime.localizeTimeIntervalFromDate(contextScan.RemainingTime, tr);
							}
							else
							{
								if(contextScan.HasLastStopTime)
								{
									return tr.Localize("DurationSinceLastStopText", {"DurationSinceLastStop" : DateTime.localizeTimeIntervalFromDateFullFormat(contextScan.DurationSinceLastStop, tr)});
								}
								else
								{
									return tr.Localize("Unknown");
								}
							}
						}
                        elide: Text.ElideRight
						onClicked: contextScan.ShowScanObjectReport();
					}
				}
				Row
				{
					id: textCount
                    anchors.left: parent.left
                    Text{text: tr.Localize("ScannedObjectCountName"); font: commonFontStyles.standardCommonTextFont}
                    Text{text: tr.Localize("ScannedObjectCountText", {"ScannedObjectCount":contextScan.ScannedObjectCount, 
												     "ScannedObjectCountFmt":tr.LocalizeNumber(contextScan.ScannedObjectCount)});
			     color: "Gray"; font: commonFontStyles.standardCommonTextFont}
				}
				Row
				{
					id: threatsCountInfoVulnerability
                    anchors.left: parent.left
					visible: checkScanTaskType("Vulnerability")
                    Text{text: tr.Localize("VulnerabilityScan_CountName"); font: commonFontStyles.standardCommonTextFont}
                    Text{text: contextScan.DetectedThreatCount ? contextScan.DetectedThreatCount :  tr.Localize("ObjectsAreAbsent");
					color: "Gray"; font: commonFontStyles.standardCommonTextFont}
				}
				Row
				{
					visible: !threatsCountInfoVulnerability.visible
                    anchors.left: parent.left
                    Text{text: tr.Localize("DetectedThreatCountName"); font: commonFontStyles.standardCommonTextFont}
                    Text{text: contextScan.DetectedThreatCount ? contextScan.DetectedThreatCount :  tr.Localize("ObjectsAreAbsent");
					color: "Gray"; font: commonFontStyles.standardCommonTextFont}
				}
				Row
				{
					visible: !threatsCountInfoVulnerability.visible && contextScan.DetectedThreatCount > 0
                    anchors.left: parent.left
                    Text{text: tr.Localize("NeutralizedThreatCountName"); font: commonFontStyles.standardCommonTextFont}
                    Text{text: contextScan.NeutralizedThreatCount
					color: "Gray"; font: commonFontStyles.standardCommonTextFont}
				}
			}
		}

		FocusScope
		{
			objectName: "Specific"
			id: specific
			anchors.top: commonText.bottom
            anchors.topMargin: 10
			width:	parent.width
            property bool hasContent: (contextScan.IsRunning && checkScanTaskType("Full")) || (checkScanTaskType("Vulnerability") && !contextScan.IsNeverRun && !contextScan.IsFailed)
            // FullScan specific
            Item
            {
                id:		actionOnTaskCompleted
                anchors.fill: parent
                visible: contextScan.IsRunning && checkScanTaskType("Full")
                Column
                {
                    spacing: 4
                    anchors.left: parent.left
                    Text
                    {
                        id: 			actionOnTaskCompletedDescription
                        text:			tr.Localize("FullScan_ActionOnFinish")
                        anchors.left: parent.left
                        color:			"Black"
                        wrapMode: 		Text.Wrap
                        font:			commonFontStyles.standardCommonTextFont
                    }
                    Widgets.EnumCombo
                    {
                        id:					actionOnTaskCompletedCombo
                        tabOrder: 2
                        focus: checkScanTaskType("Full") && contextScan.IsRunning
                        anchors.left: parent.left
                        objectName:			"ActionOnTaskCompleted"
                        target: contextScan
                        property: "ActionOnTaskCompleted"
                        when: contextScan.IsRunning && checkScanTaskType("Full")
                        localizationObject: tr
                    }
                }
            }
			// Vulnerability specific
			Item
			{
				objectName: "vulnerabilitiesList"
				id: vulnerabilitiesList
	            anchors.bottom: parent.bottom
				anchors.fill: parent

	            Widgets.GrayButton
	            {
					objectName: "ShowVulnerabilitiesListButton"
					focus: checkScanTaskType("Vulnerability")
	            	setFocusOnPressed: true
	            	tabOrder: 2
	                anchors.left: parent.left
					text: tr.Localize("VulnerabilityScan_ShowObjectListButtonText")
                    visible: !contextScan.IsRunning
					onClicked: context.ShowVulnerabilityList.Invoke()
				}

				visible: checkScanTaskType("Vulnerability") && !contextScan.IsNeverRun && !contextScan.IsFailed;
			}
		}
	}
}
