import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper

FocusScope
{
    property variant context: SettingsHelper.GetPageContext(Settings, "SafeBanking")

    id: scope
    objectName: "FocusRect"
    anchors.left: parent.left
    anchors.right: parent.right

    Rectangle
    {
        id: listRect
        objectName: "ListRect"
        width: parent.width
        height: parent.height

        enabled: context.safeBankingEnabled

        border
        {
            width: 1
            color: "lightgray"
        }

        function getCurrentTextColor(itemId)
        {
            if (listRect.enabled)
            {
                if (urlSettingsList.current === itemId)
                    return "white";
                else
                    return "black";
            }
            else
            {
                return "gray";
            }
        }

        function getCurrentSelectColor()
        {
            return listRect.enabled ? "#0d3256" : "#adcbff";
        }

        Column
        {
            y: 1
            objectName: "Column"
            anchors.left: parent.left
            anchors.leftMargin: 1
            anchors.right: parent.right

            Item
            {
                id: toolBar
                objectName: "Toolbar"
                width: parent.width
                height: toolImage.height

                BorderImage
                {
                    id: toolImage

                    source: "../../common/images/settings/firewall/toolbar.png"

                    visible: listRect.enabled

                    anchors.left: parent.left
                    anchors.right: parent.right
                    mirror: Window.Mirror

                    Widgets.DPIScaler {changeHeight: true}
                }

                Row
                {
                    id: toolButtons
                    anchors.left: parent.left
                    anchors.leftMargin: 1
                    anchors.verticalCenter: parent.verticalCenter
                    objectName: "Row"
                    height: editButton.height + 4

                    spacing: 2

                    SettingsCommon.SettingsToolbarButton
                    {
                        id: addButton

                        iconImage: "../../common/images/safe_banking/safe_banking_add" + (enabled ? "" : "_disabled") + ".png"
                        anchors.verticalCenter: parent.verticalCenter
                        objectName: "Add"
                        text: tr.Localize("Add")
                        enabled: listRect.enabled
                        onClicked:
                        {
                            context.AddUrlSettings()
                        }
                    }

                    SettingsCommon.SettingsToolbarButton
                    {
                        id: editButton

                        iconImage: "../../common/images/settings/firewall/edit" + (enabled ? "" : "_disabled") + ".png"
                        anchors.verticalCenter: parent.verticalCenter
                        objectName: "Modify"
                        text: tr.Localize("Modify")
                        enabled: listRect.enabled && !!urlSettingsList.current && urlSettingsList.current.canEdit
                        onClicked: urlSettingsList.current ? urlSettingsList.current.editUrl() : null
                    }

                    SettingsCommon.SettingsToolbarButton
                    {
                        iconImage: "../../common/images/settings/firewall/delete" + (enabled ? "" : "_disabled") + ".png"
                        anchors.verticalCenter: parent.verticalCenter
                        objectName: "Remove"
                        text: tr.Localize("Remove")
                        enabled: listRect.enabled && !!urlSettingsList.current && urlSettingsList.current.canDelete
                        onClicked: urlSettingsList.current ? urlSettingsList.current.deleteUrl() : null
                    }
                }

                Widgets.DPIScaler {changeHeight: true}
            }

            Rectangle
            {
                id: separator
                width: parent.width
                height: 1
                color: "lightgray"
            }

            ListView
            {
                id: urlSettingsList

                anchors.left: parent.left
                anchors.right: parent.right
                height: listRect.height - toolBar.height - separator.height

                model: context.urlSettings

                clip: true

                property Item current

                onModelChanged:
                {
                    urlSettingsList.current = null
                }

                Widgets.ScrollBar
                {
                    id: userListScrollBar
                    objectName: "FlickableScrollBar"

                    anchors.right: urlSettingsList.right
                    anchors.top: urlSettingsList.top
                    anchors.bottom: urlSettingsList.bottom
                    anchors.bottomMargin: 1

                    target: urlSettingsList

                    visible: urlSettingsList.contentHeight > urlSettingsList.height
                }

                delegate: Item
                {
                    id: urlSettingsItem

                    anchors.left: parent.left
                    anchors.right: parent.right

                    height: titleText.height + 10

                    property bool canEdit: true
                    property bool canDelete: EnumExtension.GetKey(modelData, "urlType") !== "DefaultSettings"

                    function editUrl()
                    {
                        if(EnumExtension.GetKey(modelData, "urlType") !== "DefaultSettings")
                            context.ModifyUrlSettings(index);
                        else
                            context.ModifyDefaultSettings();
                    }

                    function deleteUrl()
                    {
                        urlSettingsList.current = null
                        context.RemoveUrlSettings(index);
                    }

                    Rectangle
                    {
                        visible: urlSettingsList.current === urlSettingsItem
                        color: listRect.getCurrentSelectColor()
                        anchors.left: parent.left
                        anchors.top: parent.top
                        anchors.bottom: parent.bottom

                        width: parent.width - (urlSettingsList.contentHeight > urlSettingsList.height ? userListScrollBar.width : 0)

                        z: -1
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        id: titleText

                        width: parent.width * 4 / 7 - anchors.leftMargin

                        anchors.left: parent.left
                        anchors.leftMargin: 9
                        anchors.verticalCenter: urlSettingsItem.verticalCenter

                        color: listRect.getCurrentTextColor(parent)

                        elide: Text.ElideRight

                        text: EnumExtension.GetKey(modelData, "urlType") !== "DefaultSettings" ? modelData.title : tr.Localize("OtherBanksAndPaymentSystems");
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        width: parent.width * 3 / 7 - 2 * anchors.leftMargin
                        anchors.left: titleText.right
                        anchors.leftMargin: 9
                        anchors.verticalCenter: urlSettingsItem.verticalCenter

                        elide: Text.ElideRight

                        text: tr.Localize(modelData.actionType ? EnumExtension.GetKey(modelData, "actionType") : EnumExtension.GetKey(modelData, "actionType"))
                        color: listRect.getCurrentTextColor(parent)
                    }

                    MouseArea
                    {
                        anchors.fill: parent

                        acceptedButtons: Qt.LeftButton

                        onDoubleClicked: editUrl();
                        onClicked:
                        {
                            if (listRect.enabled) {
                                urlSettingsList.current = urlSettingsItem;
                            }
                        }
                    }

                    Widgets.DPIScaler {changeHeight: true}
                }
            }
        }
    }
}
