import QtQuick 1.1
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper

Column
{
	width:				parent.width
	spacing:			3
	objectName: "scanDesc"

	Widgets.KeyNavigation
	{
		id: keyNavigations2
		focusedItems: { return [timeLeft, durationSinceLastStop, ksnStatistics, onCompleteAction] }
	}
	Keys.onUpPressed: keyNavigations2.onSetPrevious(event)
	Keys.onDownPressed: keyNavigations2.onSetNext(event)

	Component.onCompleted: setFocusPosition()

	function setFocusPosition()
	{
		if (taskModel.IsFailed)
			return;
		if (taskModel.IsRunning)
			timeLeft.focus = true;
		else
			durationSinceLastStop.focus = true;
	}

    Widgets.ConditionalLoader
    {
        width: parent.width
        when: taskModel.IsRunning && !taskModel.IsStopping || EnumHelper.getKey(taskModel, "Type") == "CustomArea"
        conditionSource: Qt.resolvedUrl("TaskItemCurrentObjectElement.qml")
		objectName: "currentObjectLoader"
    }
    Widgets.ConditionalLoader
    {
        id: timeLeft
        width: parent.width
        when: taskModel.IsRunning
        conditionSource: Qt.resolvedUrl("TaskItemTimeLeftElement.qml")
        onFocusChanged: item ? item.setFocus(focus) : null
		objectName: "timeLeftLoader"
    }
    Widgets.ConditionalLoader
    {
        id: durationSinceLastStop
        width: parent.width
        when: !taskModel.IsRunning
        conditionSource: Qt.resolvedUrl("TaskItemDurationSinceLastStopElement.qml")
        onFocusChanged: item ? item.setFocus(focus) : null
		objectName: "scanDurationLoader"
    }
	TaskItemScannedObjectCountElement {}
	TaskItemThreatCountElement {}
    Widgets.ConditionalLoader
    {
        width: parent.width
        when: taskModel.DetectedThreatCount > 0
        conditionSource: Qt.resolvedUrl("TaskItemNeutralizedThreatCountElement.qml")
		objectName: "scanNeutralizedLoader"
    }
    Widgets.ConditionalLoader
    {
        id: ksnStatistics
        width: parent.width
        when: EnumHelper.getKey(taskModel, "Type") == "CustomArea" && taskModel.IsKsnStatisticsAvailable && !taskModel.IsRunning
        conditionSource: Qt.resolvedUrl("TaskItemKsnStatisticsElement.qml")
		objectName: "scanKsnLoader"
    }
    Widgets.ConditionalLoader
    {
        id: onCompleteAction
        width: parent.width
        when:	EnumHelper.getKey(taskModel, "Type") == "Full" && taskModel.IsRunning;
        conditionSource: Qt.resolvedUrl("TaskItemOnCompleteActionElement.qml")
		objectName: "scanOnCompleteLoader"
    }
}

