import QtQuick 1.1
import "../fonts" as Fonts
import "../Common.js" as Common
import "../Stat.js" as Stat

Item
{
	id:comboBox
	objectName: "comboBox"
	property variant standartFontStyles: Fonts.Common{}

	property int tabOrder: 1

	property variant actionList
	property int defaultAction: 0

	height: childrenRect.height
	width: childrenRect.width

	signal pressed(int index)
	onPressed: currentIndex = index;
		
	// internal use only!
	property variant menu
	property string defaultText
	property alias defaultIconSource: button.iconImage
	property QtObject tempElement // Helper. For a correct object cast
	property int currentIndex: 0

	function doOnMenuItemPressed(elementIndex, elementName)
	{
		var path = Common.buildDelegatelessPath(comboBox)  + ".popupMenu." + elementName;
        Stat.onButtonClick(path);
		comboBox.pressed(elementIndex);
	}

	onActionListChanged: populateMenu();
	function populateMenu()
	{
		if(comboBox.menu != undefined)
			comboBox.menu.destroy();
		if(actionList == undefined)
			return;

		var menuText = 'import QtWidgetProxies 1.0; PopupMenu{';
		menuText += ' styleSheet: "border-width:1px; border-style: solid; border-color: gray;';
        menuText += ' background-color: rgb(255, 255, 255);selection-background-color: rgb(26, 152, 133); font:10pt FranklinGothicMediCondTT;";'
		menuText += "width: button.width;"
		menuText += ' items: ['
		var elementIndex = 0;
		while(elementIndex < actionList.length)
		{
			if(elementIndex > 0)
				menuText +=',';
			tempElement = actionList[elementIndex];
			menuText += 'PopupMenuAction{text : "';
			menuText += tempElement.name;
			menuText += '; onTriggered:comboBox.doOnMenuItemPressed(';
	        menuText += elementIndex;
			menuText += ", \"";
			menuText += tempElement.name;
	        menuText += '\") }';
			++elementIndex;
		}
		menuText += ']}';
		menu = Qt.createQmlObject(menuText, comboBox, "dynamicMenu");
		if(defaultAction < actionList.length)
		{
			tempElement = actionList[defaultAction];
			defaultText = tempElement.name;
			currentIndex = defaultAction;
		}
	}

	function getNearRect(button)
	{
		return Qt.rect(button.x, button.y, button.width, button.height)
	}

    GrayButton
	{
		id: button
	   	focusRectEnabled: false
		FocusRect
		{
			target: button
			anchors.topMargin: 2
			anchors.bottomMargin: 3
			anchors.leftMargin: 2
			anchors.rightMargin: 3
		}

				backgroundImage: "../images/widgets/ddl_gray_normal.png"
				hoverImage:      "../images/widgets/ddl_gray_hover.png"
				pressedImage:    "../images/widgets/ddl_gray_pressed.png"

		text:       comboBox.defaultText
        horizontalMargin: 12
        spacing: 8
        borderLeft:  30
        borderRight: 30


        buttonHeight: 50
        buttonWidth:  340
		textLeft:     true
		mirrorBackground: Window.Mirror
		DPIScaler
		{
			widthProperty: "buttonWidth"
			heightProperty: "buttonHeight"
			changeSize: true
		}
        textfont: comboBox.standartFontStyles.standardComboFont

		onClicked:
		{
			comboBox.menu.ShowNearItem(comboBox.getNearRect(button));
			menu.focus = true;
			button.focus = true;
		}

		Keys.onDownPressed:
		{
			if (event.modifiers & Qt.AltModifier)
				clicked();
			else if (comboBox.currentIndex + 1 < actionList.length)
				comboBox.pressed(comboBox.currentIndex + 1);
		}
		Keys.onUpPressed:
		{
			if (comboBox.currentIndex > 0)
				comboBox.pressed(comboBox.currentIndex - 1);
		}
	}
}
