import QtQuick 1.1
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper
import "../common/widgets" as Widgets
import "../common/Colors.js" as Colors
import "../common/DateTime.js" as DateTime
import "../common/ProductTypeHelper.js" as ProductTypeHelper

Rectangle
{
    id:page
    objectName: "licensePage"
    property int tabOrder: 1

    property variant model : MainWindow.licenseManager
    property variant commonFontStyles: Fonts.Common{}

    function getLicenseImage(object, licenseState)
    {
        return EnumHelper.convert(object, licenseState, {
			"Actual":"../common/images/license/pic_license_normal.png",
			"Invalid":"../common/images/license/pic_license_expired.png",
			"Unknown":"../common/images/license/pic_license_unknown.png",
			"HasWarnings":"../common/images/license/pic_license_normal.png"});
    }

    function getLicenseRemainingDaysCount()
    {
        return model.licenseProperties.licenseRemainingDaysCount;
    }

	Component.onCompleted:
	{
		if(model.IPM != undefined)
			model.IPM.reportShowStatistics();
	}

    function getStatusColor(object, licenseState)
    {
        return EnumHelper.convert(object, licenseState, {
            "Actual":Colors.green,
            "Invalid":Colors.red,
            "Unknown":"gray",
            "HasWarnings":Colors.green});
    }

	Image
	{
			id: licenseImage
			source: getLicenseImage(page.model, "ActiveLicenseState");
			anchors.left:parent.left;anchors.leftMargin:30
			anchors.top:parent.top;anchors.topMargin:34
	}

    Component
    {
         id: infoDelegate
         Item
         {
			 anchors.left: parent.left
             width:commonItem.width;
             height:commonItem.height
             visible: true;
			property int tabOrder: licenseStatus.visible ? 1 : 0
             Widgets.StaticLabel
             {
                 id:commonItem
                 function prepareVariables()
                 {
					var variableMap = {
						"LicensePcCount" : page.model.licenseProperties.licensePcCount,
						"LicenseLifespan" : DateTime.localizeTimeIntervalFromDaysCount(page.model.licenseProperties.licenseLifespanInDays, tr),
						"LicenseType" : tr.Localize(page.model.licenseProperties.licenseType),
                        "LicenseExpirationDate" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
                        "SubscriptionExpirationDateTimeWithSecond" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
                        "SubscriptionExpirationDate" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
                        "LicenseExpirationDateTimeWithSeconds" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
						"LicenseRemainingDaysCount" : page.getLicenseRemainingDaysCount(),
                        "TicketValidFromDate" : tr.LocalizeDateTimeShort(page.model.ticketValidFromDate),
                        "TicketValidToDate" : tr.LocalizeDateTimeShort(page.model.ticketValidToDate),
                        "ActivationDate" : tr.LocalizeDateTimeShort(page.model.activationDate),
                        "InstallationDate" : tr.LocalizeDateTimeShort(page.model.installationDate)
					};
					return variableMap;
                 }

                 caption: tr.Localize(model.modelData.name);
                 value: model.modelData.shouldLocalize ? tr.Localize(model.modelData.value, prepareVariables()) : model.modelData.value;
                 captionFont:commonFontStyles.standardCommonTextFont
                 valueFont:commonFontStyles.standardCommonTextFont
                 valueColor:model.modelData.isLicenseState ? page.getStatusColor(page.model, "ActiveLicenseState") : "gray";
                 isWrapMode: false;
                 wrapToBottom: false;
                 visible: !licenseStatus.visible
				 anchors.left: parent.left
             }

             Row
             {
                 id: licenseStatus
                 visible: model.modelData.isLicenseNumber
				 anchors.left: parent.left
                 spacing: 2
                 Text
                 {
                     text: tr.Localize(model.modelData.name);
                     font: commonFontStyles.standardCommonTextFont
					 horizontalAlignment: Text.AlignLeft
                 }
                 Widgets.Hyperlink
                 {
                     id: licenseNumber
					 objectName: "licenseNumber"
                     text: model.modelData.value
                     onClicked: page.model.ShowLicenseInfoDialog()
                 }
             }

             Image
             {
                 id: licenseRemove
                 objectName:	"licenseRemove"
                 source: "../common/images/license/Cross_ico.png";
                 anchors.left:licenseStatus.right; anchors.leftMargin:3
                 anchors.top:licenseStatus.top; anchors.topMargin:3
                 visible: model.modelData.isLicenseNumber;
                 property int tabOrder: 2
                 Widgets.FocusRect {}
                 function clicked()
                 {
					page.model.DeletePrimaryLicense()
                 }
                 Keys.onReturnPressed: licenseRemove.clicked()
				Keys.onEnterPressed: licenseRemove.clicked()
                 MouseArea
                 {
                     anchors.fill: parent
                     hoverEnabled: true;
                     onClicked: licenseRemove.clicked()
                     Widgets.Clickable {}
                 }
             }
         }
    }

    Flickable
    {
        id:scrollPane
        objectName: "scrollPane"
        anchors.left:licenseImage.right;anchors.leftMargin:28
        anchors.top:licenseImage.top
        anchors.topMargin: 3
        anchors.right:parent.right;
        anchors.bottom: page.bottom;
		clip: true
		interactive: scrollbar.visible

        contentHeight: choiceBars.height

        Column
		{
			id: choiceBars
			objectName: "choiceBars"
			width: parent.width
			height: childrenRect.height
			anchors.left: parent.left
            spacing: 25

			ListView
		    {
		        id:infoList
		        objectName: "infoList"
		        width: parent.width
		        model:page.model.LicenseInfo
		        interactive: false
                delegate: infoDelegate
                spacing: 8
				anchors.left: parent.left
		        onContentHeightChanged: height = contentHeight
		        Component.onCompleted: height = contentHeight
		    }
			function getIconImage(object, licenseState)
		    {
		        return "../common/images/ico_" + EnumHelper.convert(object, licenseState, {
		            "Actual":"info",
		            "Invalid":"danger",
		            "Unknown":"info",
		            "HasWarnings":"warning"}) + "_24.png";
		    }

            Item
            {
                objectName: "choiceBarWrapper"
                width: parent.width
                height: childrenRect.height
                anchors.left: parent.left

                Widgets.ChoiceBar
                {
                    id: activeChoiceBar
                    objectName: "activeChoiceBar"
                    visible:model.ShouldShowActiveLicenseBlock
                    shouldShowReserveCode:false
                    width: parent.width
                    maxHeight: contentHeight
                    anchors.top: parent.top
                    anchors.left: parent.left
                    backgroundImage: context.activeLicenseBlockBackgroundImage;
                    backgroundImageBorder
                    {
                        left: context.activeLicenseBlockBackgroundImageLeftBorder;
                        right: context.activeLicenseBlockBackgroundImageRightBorder;
                        top: context.activeLicenseBlockBackgroundImageTopBorder;
                        bottom: context.activeLicenseBlockBackgroundImageBottomBorder;
                    }
                    function getSubscriptionOkHeaderDescription()
                    {
						if (!page.model.licenseProperties.shouldShowSubscriptionRemainingDays)
						{
							return tr.Localize(page.model.licenseProperties.stateOkSubscriptionHeaderText);
						}

						var remainingDaysCount = page.getLicenseRemainingDaysCount();
						return (remainingDaysCount != 0)
							? tr.Localize("SubscriptionRemainingDaysCount", {"LicenseRemainingDaysCount" : remainingDaysCount})
							: tr.Localize("SubscriptionExpiresToday");
                    }
                    function getActiveLicenseBlockHeader()
                    {
                        if(model.activeLicenseBlockUsesLNCS)
                            return model.activeLicenseBlockHeaderLNCS;
                        return tr.Localize(model.activeLicenseBlockHeaderKey, {
                                "SubscriptionExpirationDate" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
                                "SubscriptionOkHeaderDescription" : getSubscriptionOkHeaderDescription()
                            });
                    }
                    caption: getActiveLicenseBlockHeader()
                    captionLeftImage: choiceBars.getIconImage(page.model, "ActiveLicenseState")

                    function getFunctionalityDisabledAfterGrace()
                    {
                        switch (page.model.licenseProperties.licenseType)
                        {
                        case "LicenseTypeSubscriptionProtection":
                            return tr.Localize("FunctionalityDisabledForExpiredSubscriptionProtection");
                        case "LicenseTypeSubscription":
                            return tr.Localize("FunctionalityDisabledForExpiredSubscription");
                        default:
                            return "";
                        }
                    }

                    function getActiveLicenseBlockText()
                    {
                        if(model.activeLicenseBlockUsesLNCS)
                            return model.activeLicenseBlockTextLNCS;
                        return tr.Localize(model.activeLicenseBlockTextKey, {
                            "ProductName" : ProductTypeHelper.getProductName(tr, context),
                            "ProductNameFull" : ProductTypeHelper.getProductNameFull(tr, context),
                            "FunctionalityLevelDescription" : tr.Localize(page.model.licenseProperties.protectionLevelDescription) + tr.Localize(page.model.updaterLevelDescription),
                            "LicenseRemainingDaysCount" : getLicenseRemainingDaysCount(),
                            "LicenseGraceDaysCount" : page.model.licenseProperties.graceDaysCount,
                            "LicensingStatusTrialRemain" : getLicenseRemainingDaysCount() ?
                                    tr.Localize("LicenseRemain", {"LicenseRemainingDaysCount" : getLicenseRemainingDaysCount()}) :
                                    tr.Localize("LicenseEndsToday"),
                            "PreinstalledCode" : page.model.licenseProperties.preinstalledCode,
                            "FunctionalityDisabledAfterGrace" : getFunctionalityDisabledAfterGrace(),
                            "StateOkSubscriptionText" : tr.Localize(page.model.licenseProperties.stateOkSubscriptionText, {
                                "SubscriptionExpirationDate" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate)
                                })
                        });
                    }
                    description: getActiveLicenseBlockText()
                    buttonListModel: page.model.ActiveLicenseBlockButtonList
                    localizer: tr
                    model: page.model
                    onLinkClicked:
                    {
                        page.model.IPM.reportActionStatistics("LNCSLinkInLicenseManager");
                        page.model.IPM.openUrl(link, "LNCSLinkInLicenseManager");
                    }
					onCaptionLinkClicked:
					{
						page.model.IPM.reportActionStatistics("LNCSLinkInLicenseManager");
                        page.model.IPM.openUrl(link, "LNCSLinkInLicenseManager");
					}
                }

                Widgets.ChoiceBar
                {
                    objectName: "reserveChoiceBar"

                    property bool bothChoiceBarsAreVisible: activeChoiceBar.visible && visible

                    visible: model.ShouldShowReserveCodeBlock
                    shouldShowReserveCode:model.ShouldShowReserveCode
                    anchors.top: bothChoiceBarsAreVisible ? activeChoiceBar.bottom : parent.top
                    anchors.topMargin: bothChoiceBarsAreVisible ? 25 : 0
                    anchors.left: parent.left

                    width: parent.width
                    maxHeight: contentHeight

                    caption: tr.Localize(model.ReserveCodeBlockHeader);
                    captionLeftImage: choiceBars.getIconImage(page.model, "ReserveCodeState")
                    description: tr.Localize(model.ReserveCodeBlockText, {"ReserveCode" : page.model.licenseProperties.reserveCodeUnmasked});
                    buttonListModel:page.model.ReserveCodeBlockButtonList
                    localizer: tr
                    model:page.model
                }
            }
		}
	}
	
    Widgets.ScrollBar
    {
        id:scrollbar
        target:scrollPane
        anchors.top: parent.top;
        anchors.right: parent.right;
        anchors.bottom: parent.bottom;
    }
}
