import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "ManageSettingsPage"

    property int helpId: HelpMapper.ManageSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "ManageSettings")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "ManageSettingsSettings" }

    Column
    {
        objectName: "Column"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "ManageSettingsSection"
            body: Column
            {
                objectName: "ManageSettingsGeneral"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description_" + ProductTypeHelper.productTypeToString(context))
                    wrapMode: Text.Wrap
                }

                Column
                {
                    objectName: "SettingsFileColumn"
                    width: parent.width
                    spacing: Margins.settingsAfterTextSpacing

                    SettingsCommon.SettingsStandardText
                    {
                        text: tr.Localize("SettingsFileDescription")
                        anchors.left: parent.left
                        width: parent.width
                        wrapMode: Text.Wrap
                    }

                    SettingsCommon.SettingsButton
                    {
                        objectName: "Save"
                        anchors.left: parent.left
                        text: tr.Localize("Save")
                        onClicked: context.SaveSettings()
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "LoadSettings"
            width: parent.width
            name: tr.Localize("LoadSettings")

            body: Column
            {
                objectName: "LoadSettingsColumn"
                width: parent.width
                spacing: Margins.settingsAfterTextSpacing

                SettingsCommon.SettingsStandardText
                {
                    text: tr.Localize("LoadSettingsDescription")
                    anchors.left: parent.left
                    width: parent.width
                    wrapMode: Text.Wrap
                }

                SettingsCommon.SettingsButton
                {
                    objectName: "Load"
                    text: tr.Localize("Load")
                    onClicked: context.LoadSettings()
                    anchors.left: parent.left
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "RestoreSettings"
            width: parent.width
            name: tr.Localize("RestoreSettings")

            body: Column
            {
                objectName: "RestoreSettingsColumn"
                width: parent.width
                spacing: Margins.settingsAfterTextSpacing

                SettingsCommon.SettingsStandardText
                {
                    text: tr.Localize("RestoreSettingsDescription")
                    anchors.left: parent.left
                    width: parent.width
                    wrapMode: Text.Wrap
                }

                SettingsCommon.SettingsButton
                {
                    id: restoreButton
                    objectName: "Restore"
                    text: tr.Localize("Restore")
                    onClicked: context.RestoreSettings()
                    anchors.left: parent.left
                }
            }
        }
    }
}
