import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "SettingsMargins.js" as Margins
import "../common/fonts" as Fonts

SettingsSection
{
    property variant context

    objectName: "SecurityLevelSection"
    Localizer { id: tr; scope: "SettingsSecurityLevel"; }
    name: tr.Localize("SecurityLevel")

    body: Column
    {
        objectName: "Column"
        spacing: Margins.settingsInnerSpacing

        Row
        {
            spacing: 15
            width: parent.width

            objectName: "Row"

            EnumSlider
            {
            	objectName: "EnumSlider"
                visible: parent.visible && !context.isCustomLevel
                target: context
                property: "predefinedLevel"
                hasMarks1: true
                hasMarks2: true
                orientation: Qt.Vertical
                height: 80

                Widgets.DPIScaler
                {
                    id: dpiScaler
                    changeSize: true
                }
            }

            Item
            {
                id: texts

                property string levelName
                property variant commonFontStyles: Fonts.Common{}

                width: childrenRect.width
                height: childrenRect.height

                visible: !context.isCustomLevel

                levelName:
                {
                    var prop = "predefinedLevel";
                    return EnumExtension.GetKey(context, prop) + (context[prop] ? "" : "");
                }

                SettingsStandardText
                {
                    id: levelText
                    anchors
                    {
                        left: parent.left
                        top: parent.top
                    }
                    text: tr.Localize(texts.levelName + "Caption")
                    font: commonFontStyles.standardSettingsBoldTextFont
                    color: parent.enabled ? "black" : "grey"
                }

                SettingsStandardText
                {
                    id: description1Text
                    anchors
                    {
                        left: levelText.left
                        leftMargin: 15
                        top: levelText.bottom
                        topMargin: 10
                    }
                    text: tr.Localize(texts.levelName + "Description1")
                    font: commonFontStyles.standardSettingsTextFont
                    color: parent.enabled ? "black" : "grey"
                }

                SettingsStandardText
                {
                    id: description2Text
                    anchors
                    {
                        left: description1Text.left
                        top: description1Text.bottom
                        topMargin: 2
                    }
                    text: tr.Localize(texts.levelName + "Description2")
                    font: commonFontStyles.standardSettingsTextFont
                    color: parent.enabled ? "black" : "grey"
                }

                Widgets.DPIScaler
                {
                    id: dpiScaler2
                    changeSize: true
                }
            }
        }

        Text
        {
            visible: parent.visible && context.isCustomLevel
            text: tr.Localize("CustomCaption")
            font.bold: true
        }

        Row
        {
            objectName: "ButtonsRow"
            width: parent.width
            spacing: Margins.settingsHorizontalButtonSpacing

            Widgets.GrayButton
            {
                objectName: "SettingsMore"
                text: tr.Localize("SettingsMore")
                onClicked: context.Edit()
            }

            Widgets.GrayButton
            {
                objectName: "DefaultLevel"
                text: tr.Localize("DefaultLevel")
                enabled: context.canSetDefault
                onClicked: context.SetDefault()
            }
        }
    }
}


